pub enum Error {
EndOfBuffer,
OutOfBounds,
InvalidType,
}
Error type indicating why serialization failed
End of buffer was reached, before object could be serialized.
Happens if the data type can not be serialized. For example if a sequence is not sized.
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
Used when a
Serialize implementation encounters any error
while serializing a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.